@@ -17,7 +17,7 @@ use Data::Compare; # Exports Compare()
 $Storable::Deparse  = 1;
 $Storable::Eval     = 1;
 
-our $VERSION = '0.42';
+our $VERSION = '0.43';
 
 use Class::Tiny {
     registry        => sub {{}},
@@ -93,7 +93,10 @@ sub snapshot {
         $es = $es->after($cached_sn->timestamp);
 
         # Nothing? Great!
-        return $self->_cached_snapshot if $es->size == 0;
+        return EventStore::Tiny::Snapshot->new(
+            state       => clone($self->_cached_snapshot->state),
+            timestamp   => $self->_cached_snapshot->timestamp,
+        ) if $es->size == 0;
 
         # Still something? Start here
         $state = clone $cached_sn->state;
